@@ -8,6 +8,7 @@ that nodes are properly interconnected.
 from __future__ import annotations
 
 import os
+import warnings
 from asyncio.subprocess import Process
 from copy import copy
 from inspect import getmembers
@@ -118,16 +119,28 @@ class Pipeline:
             self,
             host: str = os.getenv("HOST", "127.0.0.1"),
             port: int = os.getenv("PORT", "8050"),
-            proxy: str = os.getenv("DASH_PROXY", None)
+            quiet: bool = False
     ) -> None:
-        """Visualize the pipeline as a
+        """Launch a server instance for monitoring the pipeline in real time
+
+        This is a blocking call intended to be run in the main application
+        process.
 
         Args:
             host: Host IP used to serve the application
             port: Port used to serve the application
-            proxy: If this application will be served to a different URL
-                via a proxy configured outside of Python, you can list it here
-                as a string of the form ``"{input}::{output}"``
+            quiet: Suppress any status messages or warnings
         """
 
-        Visualizer(self).run_server(host=host, port=port, proxy=proxy)
+        from waitress import serve
+
+        if not quiet:
+            print(f'Launching server at http://{host}:{port}')
+
+        # we increase the number of threads from 4 (the default) to 8 so the
+        # server can more efficiently handle all of the application callbacks
+        with warnings.catch_warnings():
+            if quiet:
+                warnings.simplefilter('ignore')
+
+            serve(Visualizer(self).server, host=host, port=int(port), threads=8, _quiet=quiet)
